@@ -1,8 +1,9 @@
 predict0   <- function( mod, meig0, x0 = NULL, xgroup0 = NULL, offset0 = NULL,
                         weight0 = NULL, compute_quantile = FALSE ){
 
-  if( (class( mod ) !="resf")&(class( mod ) !="esf") ){
-    stop("Error: Input model must be an output from resf or esf function")
+  #if( (class( mod ) !="resf")&(class( mod ) !="esf") ){
+  if( (inherits(mod, "resf")==FALSE)&(inherits( mod, "esf")==FALSE) ){
+      stop("Error: Input model must be an output from resf or esf function")
   }
 
   {
@@ -319,7 +320,7 @@ predict0   <- function( mod, meig0, x0 = NULL, xgroup0 = NULL, offset0 = NULL,
             kkk      <- np_xx[ ii ]-iiii
             knots    <-seq(min( X1_nvc[ ,ii ] ),max( X1_nvc[ ,ii ] ),len=kkk+2)[2:(kkk+1)]
             testt<- try(XX1_00<- ns( X1_nvc[ , ii], knots = knots ), silent=TRUE)
-            test <- class(testt)[1] == "try-error"
+            test <- inherits( testt, "try-error" )#class(testt)[1] == "try-error"
             iiii <- iiii+1
           }
 
@@ -602,7 +603,7 @@ predict0   <- function( mod, meig0, x0 = NULL, xgroup0 = NULL, offset0 = NULL,
           for(pq in 1:ncol( pq_dat0 ) ){
             ptest<-try(pq_pred<- i_sal_k( par=tr_par,y=pq_dat0[,pq],k=tr_num,noconst_last=noconst_last,
                                           bc_par=tr_bpar0,y_ms=y_ms,z_ms=z_ms,jackup=jackup ) - y_added )
-            if(class(ptest)!="try-error"){
+            if( !inherits(ptest, "try-error") ){#class(ptest)!="try-error"
               pq_dat[,pq]       <-pq_pred
             } else {
               pq_dat[,pq]       <-NA
@@ -618,7 +619,7 @@ predict0   <- function( mod, meig0, x0 = NULL, xgroup0 = NULL, offset0 = NULL,
           pq_dat   <- pq_dat0
           for(pq in 1:ncol(pq_dat0)){
             ptest<-try(pq_pred<- i_bc(par=tr_bpar,y=pq_dat0[,pq],jackup=jackup) - y_added)
-            if(class(ptest)!="try-error"){
+            if( !inherits(ptest, "try-error") ){#class(ptest)!="try-error"
               pq_pred[is.nan(pq_pred)&(pq_dat0[,pq] < 0)]<-0
               pq_pred[pq_pred < 0 ]        <- 0
               pq_dat[,pq]       <-pq_pred
